@@ -16,7 +16,7 @@ stopifnot(all.equal(
 
 
 stopifnot(all.equal(
-  stat.extend::HDR.discrete(.95, Q=qpois, f=dpois, lambda=1)[1:2],
+  stat.extend::HDR.discrete(.95, f=dpois, lambda=1)[1:2],
   stat.extend::HDR.pois(.95, 1)[1:2]
 ))
 
@@ -26,12 +26,10 @@ stopifnot(all.equal(
 ))
 
 # Below has 0 prob at 2; shall not throw an error.
-Q = function(p) ifelse(p <= .08, 1, ifelse(p <= .14, 3, ifelse(p <= .4, 4, 5)))
-f = function(x) c(.08, 0, .06, .26, .6)[floor(x)]
 
 stopifnot(inherits(  
-  stat.extend:::HDR.discrete(.95, Q, f),
-  "set"
+  stat.extend:::HDR.discrete(.95, f = function(x) c(.08, 0, .06, .26, .6)[floor(x)], supp.min = 1, supp.max = 5),
+  "hdr"
 ))
 
 
